@@ -7,7 +7,7 @@ import aiohttp
 import asyncio
 from datetime import date, datetime
 from typing import Dict, List, Literal, Optional
-from pydantic import BaseModel
+from pydantic import BaseModel, root_validator
 from ggvlib.logging import logger
 from ggvlib.twilio.parsing import to_form_field
 
@@ -23,7 +23,36 @@ class ContentType(BaseModel):
         "card",
     ]
     body: str
-    actions: List[Dict[str, str]]
+    actions: Optional[List[Dict[str, str]]]
+    items: Optional[List[Dict[str, str]]]
+    button: Optional[str]
+
+    @root_validator(pre=True)
+    def content_validator(cls, values: dict):
+        if values.get("category") == "list-picker":
+            if not values.get("items"):
+                raise ValueError("list-picker content requires an 'items' value")
+            if not values.get("button"):
+                raise ValueError("list-picker content requires an 'button' value")
+        if values.get("category") in ("quick-reply", "call-to-action"):
+            if not values.get("actions"):
+                raise ValueError("list-picker content requires an 'items' value")
+        return values
+
+    def to_dict(self) -> dict:
+        if self.category in ("quick-reply", "call-to-action"):
+            return {
+                "body": self.body,
+                "actions": self.actions,
+            }
+        elif self.category == "list-picker":
+            return {
+                "body": self.body,
+                "items": self.items,
+                "button": self.button,
+            }
+        else:
+            return {"body": self.body}
 
 
 class ContentCreateRequest(BaseModel):
@@ -34,7 +63,7 @@ class ContentCreateRequest(BaseModel):
         variables (Dict[str, str]): Variables in a dict format
         types Dict[str, Dict[str, str]]: The type of content to create
         language (str): The content language (defaults to 'en')
-    >>> new_content = ContentRequest(
+    >>> new_content = ContentCreateRequest(
     ... friendly_name="test",
     ... variables={"1": "name", "2": "11"},
     ... types=[
@@ -59,11 +88,7 @@ class ContentCreateRequest(BaseModel):
             **{k: v for k, v in cls.dict().items() if k not in exclude},
             **{
                 "types": {
-                    f"twilio/{t.category}": {
-                        "body": t.body,
-                        "actions": t.actions,
-                    }
-                    for t in cls.content_types
+                    f"twilio/{t.category}": t.to_dict() for t in cls.content_types
                 }
             },
         )
@@ -117,9 +142,7 @@ class MessagingServiceUpdateRequest(BaseModel):
         content = {to_form_field(k): v for k, v in d.items() if v}
         if list(content.keys()) == ["Sid"]:
             required = [k for k in d.keys() if k != "sid"]
-            raise ValueError(
-                f"One of the following values is required: {required}"
-            )
+            raise ValueError(f"One of the following values is required: {required}")
         return content
 
 
@@ -197,9 +220,7 @@ class Client:
         if response.status_code == accept_status_code:
             return response.json()
         else:
-            raise Exception(
-                f"Client did not accept request: {response.json()}"
-            )
+            raise Exception(f"Client did not accept request: {response.json()}")
 
 
 class MessagingServiceApiClient(Client):
@@ -212,9 +233,7 @@ class MessagingServiceApiClient(Client):
         Returns:
             dict: _description_
         """
-        return requests.get(
-            url=self.api_base_url, headers=self.json_headers
-        ).json()
+        return requests.get(url=self.api_base_url, headers=self.json_headers).json()
 
     def get(self, service_sid: str) -> dict:
         """_summary_
@@ -330,7 +349,13 @@ class MessagingApiClient(Client):
         Returns:
             List[aiohttp.ClientResponse]: A list of responses from the client
         """
-        loop = asyncio.get_event_loop()
+        try:
+            loop = asyncio.get_event_loop()
+        except RuntimeError as ex:
+            if "There is no current event loop in thread" in str(ex):
+                loop = asyncio.new_event_loop()
+                asyncio.set_event_loop(loop)
+                loop = asyncio.get_event_loop()
         return loop.run_until_complete(
             self._async_send_content(message_batch=message_batch)
         )
@@ -352,9 +377,7 @@ class MessagingApiClient(Client):
             headers=self.form_headers, trust_env=True
         ) as session:
             for request in message_batch:
-                tasks.append(
-                    self._post_async(session=session, payload=request)
-                )
+                tasks.append(self._post_async(session=session, payload=request))
             response_data = await asyncio.gather(*tasks)
             await session.close()
             return response_data
@@ -391,6 +414,46 @@ class ContentApiClient(Client):
     api_version = 1
     api_base_url = f"https://content.twilio.com/v{api_version}/Content"
 
+    def check_approval_status(self, content_sid: str) -> dict:
+        response = requests.get(
+            url=f"{self.api_base_url}/{content_sid}/ApprovalRequests",
+            headers=self.json_headers,
+        )
+        if response.status_code == 200:
+            return response.json()
+        else:
+            raise Exception(f"Client did not accept request: {response.json()}")
+
+    def delete_content(self, content_sid: str) -> None:
+        response = requests.delete(
+            url=f"{self.api_base_url}/{content_sid}",
+            headers=self.json_headers,
+        )
+        if response.status_code == 204:
+            return
+        elif response.status_code == 404:
+            logger.warning(f"The requested content_sid '{content_sid}' does not exist.")
+        else:
+            raise Exception(f"Client did not accept request: {str(response)}")
+
+    def submit_content_for_approval(
+        self, name: str, category: str, content_sid: str
+    ) -> dict:
+        response = requests.post(
+            url=f"{self.api_base_url}/{content_sid}/ApprovalRequests/whatsapp",
+            headers=self.json_headers,
+            data=json.dumps(
+                {
+                    "name": name,
+                    "category": category,
+                }
+            ),
+        )
+        if response.status_code == 201:
+            return response.json()
+        else:
+            raise Exception(f"Client did not accept request: {response.json()}")
+
     def create_content(self, payload: ContentCreateRequest) -> dict:
         """Used for creating content with the Content API
 
@@ -411,6 +474,4 @@ class ContentApiClient(Client):
         if response.status_code == 201:
             return response.json()
         else:
-            raise Exception(
-                f"Client did not accept request: {response.json()}"
-            )
+            raise Exception(f"Client did not accept request: {response.json()}")
